# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v0/proto/common/ad_type_infos.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.ads.google_ads.v0.proto.enums import call_conversion_reporting_state_pb2 as google_dot_ads_dot_googleads__v0_dot_proto_dot_enums_dot_call__conversion__reporting__state__pb2
from google.ads.google_ads.v0.proto.enums import display_ad_format_setting_pb2 as google_dot_ads_dot_googleads__v0_dot_proto_dot_enums_dot_display__ad__format__setting__pb2
from google.ads.google_ads.v0.proto.enums import mime_type_pb2 as google_dot_ads_dot_googleads__v0_dot_proto_dot_enums_dot_mime__type__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v0/proto/common/ad_type_infos.proto',
  package='google.ads.googleads.v0.common',
  syntax='proto3',
  serialized_pb=_b('\n8google/ads/googleads_v0/proto/common/ad_type_infos.proto\x12\x1egoogle.ads.googleads.v0.common\x1aIgoogle/ads/googleads_v0/proto/enums/call_conversion_reporting_state.proto\x1a\x43google/ads/googleads_v0/proto/enums/display_ad_format_setting.proto\x1a\x33google/ads/googleads_v0/proto/enums/mime_type.proto\x1a\x1egoogle/protobuf/wrappers.proto\"\xa4\x01\n\nTextAdInfo\x12.\n\x08headline\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x32\n\x0c\x64\x65scription1\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x32\n\x0c\x64\x65scription2\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\"\xf7\x02\n\x12\x45xpandedTextAdInfo\x12\x34\n\x0eheadline_part1\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x34\n\x0eheadline_part2\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x34\n\x0eheadline_part3\x18\x06 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x31\n\x0b\x64\x65scription\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x32\n\x0c\x64\x65scription2\x18\x07 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12+\n\x05path1\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12+\n\x05path2\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.StringValue\"}\n\x13\x44ynamicSearchAdInfo\x12\x32\n\x0c\x64\x65scription1\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x32\n\x0c\x64\x65scription2\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\"\xf7\x06\n\x17ResponsiveDisplayAdInfo\x12\x34\n\x0eshort_headline\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x33\n\rlong_headline\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x31\n\x0b\x64\x65scription\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x33\n\rbusiness_name\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x38\n\x14\x61llow_flexible_color\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x32\n\x0c\x61\x63\x63\x65nt_color\x18\x06 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x30\n\nmain_color\x18\x07 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x39\n\x13\x63\x61ll_to_action_text\x18\x08 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x30\n\nlogo_image\x18\t \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x37\n\x11square_logo_image\x18\n \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x35\n\x0fmarketing_image\x18\x0b \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12<\n\x16square_marketing_image\x18\x0c \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12h\n\x0e\x66ormat_setting\x18\r \x01(\x0e\x32P.google.ads.googleads.v0.enums.DisplayAdFormatSettingEnum.DisplayAdFormatSetting\x12\x32\n\x0cprice_prefix\x18\x0e \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x30\n\npromo_text\x18\x0f \x01(\x0b\x32\x1c.google.protobuf.StringValue\"\x85\x05\n\x0e\x43\x61llOnlyAdInfo\x12\x32\n\x0c\x63ountry_code\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x32\n\x0cphone_number\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x33\n\rbusiness_name\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x32\n\x0c\x64\x65scription1\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x32\n\x0c\x64\x65scription2\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x30\n\x0c\x63\x61ll_tracked\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12;\n\x17\x64isable_call_conversion\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x43\n\x1dphone_number_verification_url\x18\x08 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x37\n\x11\x63onversion_action\x18\t \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x80\x01\n\x1a\x63onversion_reporting_state\x18\n \x01(\x0e\x32\\.google.ads.googleads.v0.enums.CallConversionReportingStateEnum.CallConversionReportingState\"P\n\x1b\x45xpandedDynamicSearchAdInfo\x12\x31\n\x0b\x64\x65scription\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\"\r\n\x0bHotelAdInfo\"\x15\n\x13ShoppingSmartAdInfo\"\x17\n\x15ShoppingProductAdInfo\"\x9d\x03\n\x0bGmailAdInfo\x12;\n\x06teaser\x18\x01 \x01(\x0b\x32+.google.ads.googleads.v0.common.GmailTeaser\x12\x32\n\x0cheader_image\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x35\n\x0fmarketing_image\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12>\n\x18marketing_image_headline\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x41\n\x1bmarketing_image_description\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x63\n&marketing_image_display_call_to_action\x18\x06 \x01(\x0b\x32\x33.google.ads.googleads.v0.common.DisplayCallToAction\"\xd7\x01\n\x0bGmailTeaser\x12.\n\x08headline\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x31\n\x0b\x64\x65scription\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x33\n\rbusiness_name\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x30\n\nlogo_image\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValue\"s\n\x13\x44isplayCallToAction\x12*\n\x04text\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x30\n\ntext_color\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\"\xb0\x04\n\x0bImageAdInfo\x12\x30\n\x0bpixel_width\x18\x04 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x31\n\x0cpixel_height\x18\x05 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12/\n\timage_url\x18\x06 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x38\n\x13preview_pixel_width\x18\x07 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x39\n\x14preview_pixel_height\x18\x08 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x37\n\x11preview_image_url\x18\t \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12G\n\tmime_type\x18\n \x01(\x0e\x32\x34.google.ads.googleads.v0.enums.MimeTypeEnum.MimeType\x12*\n\x04name\x18\x0b \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x32\n\nmedia_file\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValueH\x00\x12+\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.BytesValueH\x00\x42\x07\n\x05imageB\xc6\x01\n\"com.google.ads.googleads.v0.commonB\x10\x41\x64TypeInfosProtoP\x01ZDgoogle.golang.org/genproto/googleapis/ads/googleads/v0/common;common\xa2\x02\x03GAA\xaa\x02\x1eGoogle.Ads.GoogleAds.V0.Common\xca\x02\x1eGoogle\\Ads\\GoogleAds\\V0\\Commonb\x06proto3')
  ,
  dependencies=[google_dot_ads_dot_googleads__v0_dot_proto_dot_enums_dot_call__conversion__reporting__state__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v0_dot_proto_dot_enums_dot_display__ad__format__setting__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v0_dot_proto_dot_enums_dot_mime__type__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,])




_TEXTADINFO = _descriptor.Descriptor(
  name='TextAdInfo',
  full_name='google.ads.googleads.v0.common.TextAdInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='headline', full_name='google.ads.googleads.v0.common.TextAdInfo.headline', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='description1', full_name='google.ads.googleads.v0.common.TextAdInfo.description1', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='description2', full_name='google.ads.googleads.v0.common.TextAdInfo.description2', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=322,
  serialized_end=486,
)


_EXPANDEDTEXTADINFO = _descriptor.Descriptor(
  name='ExpandedTextAdInfo',
  full_name='google.ads.googleads.v0.common.ExpandedTextAdInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='headline_part1', full_name='google.ads.googleads.v0.common.ExpandedTextAdInfo.headline_part1', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='headline_part2', full_name='google.ads.googleads.v0.common.ExpandedTextAdInfo.headline_part2', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='headline_part3', full_name='google.ads.googleads.v0.common.ExpandedTextAdInfo.headline_part3', index=2,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='description', full_name='google.ads.googleads.v0.common.ExpandedTextAdInfo.description', index=3,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='description2', full_name='google.ads.googleads.v0.common.ExpandedTextAdInfo.description2', index=4,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='path1', full_name='google.ads.googleads.v0.common.ExpandedTextAdInfo.path1', index=5,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='path2', full_name='google.ads.googleads.v0.common.ExpandedTextAdInfo.path2', index=6,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=489,
  serialized_end=864,
)


_DYNAMICSEARCHADINFO = _descriptor.Descriptor(
  name='DynamicSearchAdInfo',
  full_name='google.ads.googleads.v0.common.DynamicSearchAdInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='description1', full_name='google.ads.googleads.v0.common.DynamicSearchAdInfo.description1', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='description2', full_name='google.ads.googleads.v0.common.DynamicSearchAdInfo.description2', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=866,
  serialized_end=991,
)


_RESPONSIVEDISPLAYADINFO = _descriptor.Descriptor(
  name='ResponsiveDisplayAdInfo',
  full_name='google.ads.googleads.v0.common.ResponsiveDisplayAdInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='short_headline', full_name='google.ads.googleads.v0.common.ResponsiveDisplayAdInfo.short_headline', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='long_headline', full_name='google.ads.googleads.v0.common.ResponsiveDisplayAdInfo.long_headline', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='description', full_name='google.ads.googleads.v0.common.ResponsiveDisplayAdInfo.description', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='business_name', full_name='google.ads.googleads.v0.common.ResponsiveDisplayAdInfo.business_name', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='allow_flexible_color', full_name='google.ads.googleads.v0.common.ResponsiveDisplayAdInfo.allow_flexible_color', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='accent_color', full_name='google.ads.googleads.v0.common.ResponsiveDisplayAdInfo.accent_color', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='main_color', full_name='google.ads.googleads.v0.common.ResponsiveDisplayAdInfo.main_color', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='call_to_action_text', full_name='google.ads.googleads.v0.common.ResponsiveDisplayAdInfo.call_to_action_text', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='logo_image', full_name='google.ads.googleads.v0.common.ResponsiveDisplayAdInfo.logo_image', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='square_logo_image', full_name='google.ads.googleads.v0.common.ResponsiveDisplayAdInfo.square_logo_image', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='marketing_image', full_name='google.ads.googleads.v0.common.ResponsiveDisplayAdInfo.marketing_image', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='square_marketing_image', full_name='google.ads.googleads.v0.common.ResponsiveDisplayAdInfo.square_marketing_image', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='format_setting', full_name='google.ads.googleads.v0.common.ResponsiveDisplayAdInfo.format_setting', index=12,
      number=13, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='price_prefix', full_name='google.ads.googleads.v0.common.ResponsiveDisplayAdInfo.price_prefix', index=13,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='promo_text', full_name='google.ads.googleads.v0.common.ResponsiveDisplayAdInfo.promo_text', index=14,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=994,
  serialized_end=1881,
)


_CALLONLYADINFO = _descriptor.Descriptor(
  name='CallOnlyAdInfo',
  full_name='google.ads.googleads.v0.common.CallOnlyAdInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='country_code', full_name='google.ads.googleads.v0.common.CallOnlyAdInfo.country_code', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='phone_number', full_name='google.ads.googleads.v0.common.CallOnlyAdInfo.phone_number', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='business_name', full_name='google.ads.googleads.v0.common.CallOnlyAdInfo.business_name', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='description1', full_name='google.ads.googleads.v0.common.CallOnlyAdInfo.description1', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='description2', full_name='google.ads.googleads.v0.common.CallOnlyAdInfo.description2', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='call_tracked', full_name='google.ads.googleads.v0.common.CallOnlyAdInfo.call_tracked', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='disable_call_conversion', full_name='google.ads.googleads.v0.common.CallOnlyAdInfo.disable_call_conversion', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='phone_number_verification_url', full_name='google.ads.googleads.v0.common.CallOnlyAdInfo.phone_number_verification_url', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='conversion_action', full_name='google.ads.googleads.v0.common.CallOnlyAdInfo.conversion_action', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='conversion_reporting_state', full_name='google.ads.googleads.v0.common.CallOnlyAdInfo.conversion_reporting_state', index=9,
      number=10, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1884,
  serialized_end=2529,
)


_EXPANDEDDYNAMICSEARCHADINFO = _descriptor.Descriptor(
  name='ExpandedDynamicSearchAdInfo',
  full_name='google.ads.googleads.v0.common.ExpandedDynamicSearchAdInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='description', full_name='google.ads.googleads.v0.common.ExpandedDynamicSearchAdInfo.description', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2531,
  serialized_end=2611,
)


_HOTELADINFO = _descriptor.Descriptor(
  name='HotelAdInfo',
  full_name='google.ads.googleads.v0.common.HotelAdInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2613,
  serialized_end=2626,
)


_SHOPPINGSMARTADINFO = _descriptor.Descriptor(
  name='ShoppingSmartAdInfo',
  full_name='google.ads.googleads.v0.common.ShoppingSmartAdInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2628,
  serialized_end=2649,
)


_SHOPPINGPRODUCTADINFO = _descriptor.Descriptor(
  name='ShoppingProductAdInfo',
  full_name='google.ads.googleads.v0.common.ShoppingProductAdInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2651,
  serialized_end=2674,
)


_GMAILADINFO = _descriptor.Descriptor(
  name='GmailAdInfo',
  full_name='google.ads.googleads.v0.common.GmailAdInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='teaser', full_name='google.ads.googleads.v0.common.GmailAdInfo.teaser', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='header_image', full_name='google.ads.googleads.v0.common.GmailAdInfo.header_image', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='marketing_image', full_name='google.ads.googleads.v0.common.GmailAdInfo.marketing_image', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='marketing_image_headline', full_name='google.ads.googleads.v0.common.GmailAdInfo.marketing_image_headline', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='marketing_image_description', full_name='google.ads.googleads.v0.common.GmailAdInfo.marketing_image_description', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='marketing_image_display_call_to_action', full_name='google.ads.googleads.v0.common.GmailAdInfo.marketing_image_display_call_to_action', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2677,
  serialized_end=3090,
)


_GMAILTEASER = _descriptor.Descriptor(
  name='GmailTeaser',
  full_name='google.ads.googleads.v0.common.GmailTeaser',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='headline', full_name='google.ads.googleads.v0.common.GmailTeaser.headline', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='description', full_name='google.ads.googleads.v0.common.GmailTeaser.description', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='business_name', full_name='google.ads.googleads.v0.common.GmailTeaser.business_name', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='logo_image', full_name='google.ads.googleads.v0.common.GmailTeaser.logo_image', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3093,
  serialized_end=3308,
)


_DISPLAYCALLTOACTION = _descriptor.Descriptor(
  name='DisplayCallToAction',
  full_name='google.ads.googleads.v0.common.DisplayCallToAction',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='text', full_name='google.ads.googleads.v0.common.DisplayCallToAction.text', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='text_color', full_name='google.ads.googleads.v0.common.DisplayCallToAction.text_color', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3310,
  serialized_end=3425,
)


_IMAGEADINFO = _descriptor.Descriptor(
  name='ImageAdInfo',
  full_name='google.ads.googleads.v0.common.ImageAdInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='pixel_width', full_name='google.ads.googleads.v0.common.ImageAdInfo.pixel_width', index=0,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pixel_height', full_name='google.ads.googleads.v0.common.ImageAdInfo.pixel_height', index=1,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='image_url', full_name='google.ads.googleads.v0.common.ImageAdInfo.image_url', index=2,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='preview_pixel_width', full_name='google.ads.googleads.v0.common.ImageAdInfo.preview_pixel_width', index=3,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='preview_pixel_height', full_name='google.ads.googleads.v0.common.ImageAdInfo.preview_pixel_height', index=4,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='preview_image_url', full_name='google.ads.googleads.v0.common.ImageAdInfo.preview_image_url', index=5,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mime_type', full_name='google.ads.googleads.v0.common.ImageAdInfo.mime_type', index=6,
      number=10, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='google.ads.googleads.v0.common.ImageAdInfo.name', index=7,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='media_file', full_name='google.ads.googleads.v0.common.ImageAdInfo.media_file', index=8,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='data', full_name='google.ads.googleads.v0.common.ImageAdInfo.data', index=9,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='image', full_name='google.ads.googleads.v0.common.ImageAdInfo.image',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=3428,
  serialized_end=3988,
)

_TEXTADINFO.fields_by_name['headline'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_TEXTADINFO.fields_by_name['description1'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_TEXTADINFO.fields_by_name['description2'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_EXPANDEDTEXTADINFO.fields_by_name['headline_part1'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_EXPANDEDTEXTADINFO.fields_by_name['headline_part2'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_EXPANDEDTEXTADINFO.fields_by_name['headline_part3'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_EXPANDEDTEXTADINFO.fields_by_name['description'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_EXPANDEDTEXTADINFO.fields_by_name['description2'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_EXPANDEDTEXTADINFO.fields_by_name['path1'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_EXPANDEDTEXTADINFO.fields_by_name['path2'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_DYNAMICSEARCHADINFO.fields_by_name['description1'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_DYNAMICSEARCHADINFO.fields_by_name['description2'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_RESPONSIVEDISPLAYADINFO.fields_by_name['short_headline'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_RESPONSIVEDISPLAYADINFO.fields_by_name['long_headline'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_RESPONSIVEDISPLAYADINFO.fields_by_name['description'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_RESPONSIVEDISPLAYADINFO.fields_by_name['business_name'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_RESPONSIVEDISPLAYADINFO.fields_by_name['allow_flexible_color'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_RESPONSIVEDISPLAYADINFO.fields_by_name['accent_color'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_RESPONSIVEDISPLAYADINFO.fields_by_name['main_color'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_RESPONSIVEDISPLAYADINFO.fields_by_name['call_to_action_text'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_RESPONSIVEDISPLAYADINFO.fields_by_name['logo_image'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_RESPONSIVEDISPLAYADINFO.fields_by_name['square_logo_image'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_RESPONSIVEDISPLAYADINFO.fields_by_name['marketing_image'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_RESPONSIVEDISPLAYADINFO.fields_by_name['square_marketing_image'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_RESPONSIVEDISPLAYADINFO.fields_by_name['format_setting'].enum_type = google_dot_ads_dot_googleads__v0_dot_proto_dot_enums_dot_display__ad__format__setting__pb2._DISPLAYADFORMATSETTINGENUM_DISPLAYADFORMATSETTING
_RESPONSIVEDISPLAYADINFO.fields_by_name['price_prefix'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_RESPONSIVEDISPLAYADINFO.fields_by_name['promo_text'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_CALLONLYADINFO.fields_by_name['country_code'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_CALLONLYADINFO.fields_by_name['phone_number'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_CALLONLYADINFO.fields_by_name['business_name'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_CALLONLYADINFO.fields_by_name['description1'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_CALLONLYADINFO.fields_by_name['description2'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_CALLONLYADINFO.fields_by_name['call_tracked'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_CALLONLYADINFO.fields_by_name['disable_call_conversion'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_CALLONLYADINFO.fields_by_name['phone_number_verification_url'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_CALLONLYADINFO.fields_by_name['conversion_action'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_CALLONLYADINFO.fields_by_name['conversion_reporting_state'].enum_type = google_dot_ads_dot_googleads__v0_dot_proto_dot_enums_dot_call__conversion__reporting__state__pb2._CALLCONVERSIONREPORTINGSTATEENUM_CALLCONVERSIONREPORTINGSTATE
_EXPANDEDDYNAMICSEARCHADINFO.fields_by_name['description'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_GMAILADINFO.fields_by_name['teaser'].message_type = _GMAILTEASER
_GMAILADINFO.fields_by_name['header_image'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_GMAILADINFO.fields_by_name['marketing_image'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_GMAILADINFO.fields_by_name['marketing_image_headline'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_GMAILADINFO.fields_by_name['marketing_image_description'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_GMAILADINFO.fields_by_name['marketing_image_display_call_to_action'].message_type = _DISPLAYCALLTOACTION
_GMAILTEASER.fields_by_name['headline'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_GMAILTEASER.fields_by_name['description'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_GMAILTEASER.fields_by_name['business_name'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_GMAILTEASER.fields_by_name['logo_image'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_DISPLAYCALLTOACTION.fields_by_name['text'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_DISPLAYCALLTOACTION.fields_by_name['text_color'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_IMAGEADINFO.fields_by_name['pixel_width'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_IMAGEADINFO.fields_by_name['pixel_height'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_IMAGEADINFO.fields_by_name['image_url'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_IMAGEADINFO.fields_by_name['preview_pixel_width'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_IMAGEADINFO.fields_by_name['preview_pixel_height'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_IMAGEADINFO.fields_by_name['preview_image_url'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_IMAGEADINFO.fields_by_name['mime_type'].enum_type = google_dot_ads_dot_googleads__v0_dot_proto_dot_enums_dot_mime__type__pb2._MIMETYPEENUM_MIMETYPE
_IMAGEADINFO.fields_by_name['name'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_IMAGEADINFO.fields_by_name['media_file'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_IMAGEADINFO.fields_by_name['data'].message_type = google_dot_protobuf_dot_wrappers__pb2._BYTESVALUE
_IMAGEADINFO.oneofs_by_name['image'].fields.append(
  _IMAGEADINFO.fields_by_name['media_file'])
_IMAGEADINFO.fields_by_name['media_file'].containing_oneof = _IMAGEADINFO.oneofs_by_name['image']
_IMAGEADINFO.oneofs_by_name['image'].fields.append(
  _IMAGEADINFO.fields_by_name['data'])
_IMAGEADINFO.fields_by_name['data'].containing_oneof = _IMAGEADINFO.oneofs_by_name['image']
DESCRIPTOR.message_types_by_name['TextAdInfo'] = _TEXTADINFO
DESCRIPTOR.message_types_by_name['ExpandedTextAdInfo'] = _EXPANDEDTEXTADINFO
DESCRIPTOR.message_types_by_name['DynamicSearchAdInfo'] = _DYNAMICSEARCHADINFO
DESCRIPTOR.message_types_by_name['ResponsiveDisplayAdInfo'] = _RESPONSIVEDISPLAYADINFO
DESCRIPTOR.message_types_by_name['CallOnlyAdInfo'] = _CALLONLYADINFO
DESCRIPTOR.message_types_by_name['ExpandedDynamicSearchAdInfo'] = _EXPANDEDDYNAMICSEARCHADINFO
DESCRIPTOR.message_types_by_name['HotelAdInfo'] = _HOTELADINFO
DESCRIPTOR.message_types_by_name['ShoppingSmartAdInfo'] = _SHOPPINGSMARTADINFO
DESCRIPTOR.message_types_by_name['ShoppingProductAdInfo'] = _SHOPPINGPRODUCTADINFO
DESCRIPTOR.message_types_by_name['GmailAdInfo'] = _GMAILADINFO
DESCRIPTOR.message_types_by_name['GmailTeaser'] = _GMAILTEASER
DESCRIPTOR.message_types_by_name['DisplayCallToAction'] = _DISPLAYCALLTOACTION
DESCRIPTOR.message_types_by_name['ImageAdInfo'] = _IMAGEADINFO
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

TextAdInfo = _reflection.GeneratedProtocolMessageType('TextAdInfo', (_message.Message,), dict(
  DESCRIPTOR = _TEXTADINFO,
  __module__ = 'google.ads.google_ads.v0.proto.common.ad_type_infos_pb2'
  ,
  __doc__ = """A text ad.
  
  
  Attributes:
      headline:
          The headline of the ad.
      description1:
          The first line of the ad's description.
      description2:
          The second line of the ad's description.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v0.common.TextAdInfo)
  ))
_sym_db.RegisterMessage(TextAdInfo)

ExpandedTextAdInfo = _reflection.GeneratedProtocolMessageType('ExpandedTextAdInfo', (_message.Message,), dict(
  DESCRIPTOR = _EXPANDEDTEXTADINFO,
  __module__ = 'google.ads.google_ads.v0.proto.common.ad_type_infos_pb2'
  ,
  __doc__ = """An expanded text ad.
  
  
  Attributes:
      headline_part1:
          The first part of the ad's headline.
      headline_part2:
          The second part of the ad's headline.
      headline_part3:
          The third part of the ad's headline.
      description:
          The description of the ad.
      description2:
          The second description of the ad.
      path1:
          The text that can appear alongside the ad's displayed URL.
      path2:
          Additional text that can appear alongside the ad's displayed
          URL.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v0.common.ExpandedTextAdInfo)
  ))
_sym_db.RegisterMessage(ExpandedTextAdInfo)

DynamicSearchAdInfo = _reflection.GeneratedProtocolMessageType('DynamicSearchAdInfo', (_message.Message,), dict(
  DESCRIPTOR = _DYNAMICSEARCHADINFO,
  __module__ = 'google.ads.google_ads.v0.proto.common.ad_type_infos_pb2'
  ,
  __doc__ = """A dynamic search ad.
  
  
  Attributes:
      description1:
          The first line of the ad's description.
      description2:
          The second line of the ad's description.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v0.common.DynamicSearchAdInfo)
  ))
_sym_db.RegisterMessage(DynamicSearchAdInfo)

ResponsiveDisplayAdInfo = _reflection.GeneratedProtocolMessageType('ResponsiveDisplayAdInfo', (_message.Message,), dict(
  DESCRIPTOR = _RESPONSIVEDISPLAYADINFO,
  __module__ = 'google.ads.google_ads.v0.proto.common.ad_type_infos_pb2'
  ,
  __doc__ = """A responsive display ad.
  
  
  Attributes:
      short_headline:
          The short version of the ad's headline.
      long_headline:
          The long version of the ad's headline.
      description:
          The description of the ad.
      business_name:
          The business name in the ad.
      allow_flexible_color:
          Advertiser's consent to allow flexible color. When true, the
          ad may be served with different color if necessary. When
          false, the ad will be served with the specified colors or a
          neutral color. The default value is true. Must be true if
          main\_color and accent\_color are not set.
      accent_color:
          The accent color of the ad in hexadecimal, e.g. #ffffff for
          white. If one of main\_color and accent\_color is set, the
          other is required as well.
      main_color:
          The main color of the ad in hexadecimal, e.g. #ffffff for
          white. If one of main\_color and accent\_color is set, the
          other is required as well.
      call_to_action_text:
          The call-to-action text for the ad.
      logo_image:
          The MediaFile resource name of the logo image used in the ad.
      square_logo_image:
          The MediaFile resource name of the square logo image used in
          the ad.
      marketing_image:
          The MediaFile resource name of the marketing image used in the
          ad.
      square_marketing_image:
          The MediaFile resource name of the square marketing image used
          in the ad.
      format_setting:
          Specifies which format the ad will be served in. Default is
          ALL\_FORMATS.
      price_prefix:
          Prefix before price. E.g. 'as low as'.
      promo_text:
          Promotion text used for dyanmic formats of responsive ads. For
          example 'Free two-day shipping'.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v0.common.ResponsiveDisplayAdInfo)
  ))
_sym_db.RegisterMessage(ResponsiveDisplayAdInfo)

CallOnlyAdInfo = _reflection.GeneratedProtocolMessageType('CallOnlyAdInfo', (_message.Message,), dict(
  DESCRIPTOR = _CALLONLYADINFO,
  __module__ = 'google.ads.google_ads.v0.proto.common.ad_type_infos_pb2'
  ,
  __doc__ = """A call-only ad.
  
  
  Attributes:
      country_code:
          The country code in the ad.
      phone_number:
          The phone number in the ad.
      business_name:
          The business name in the ad.
      description1:
          The first line of the ad's description.
      description2:
          The second line of the ad's description.
      call_tracked:
          Whether to enable call tracking for the creative. Enabling
          call tracking also enables call conversions.
      disable_call_conversion:
          Whether to disable call conversion for the creative. If set to
          ``true``, disables call conversions even when ``call_tracked``
          is ``true``. If ``call_tracked`` is ``false``, this field is
          ignored.
      phone_number_verification_url:
          The URL to be used for phone number verification.
      conversion_action:
          The conversion action to attribute a call conversion to. If
          not set a default conversion action is used. This field only
          has effect if call\_tracked is set to true. Otherwise this
          field is ignored.
      conversion_reporting_state:
          The call conversion behavior of this call only ad. It can use
          its own call conversion setting, inherit the account level
          setting, or be disabled.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v0.common.CallOnlyAdInfo)
  ))
_sym_db.RegisterMessage(CallOnlyAdInfo)

ExpandedDynamicSearchAdInfo = _reflection.GeneratedProtocolMessageType('ExpandedDynamicSearchAdInfo', (_message.Message,), dict(
  DESCRIPTOR = _EXPANDEDDYNAMICSEARCHADINFO,
  __module__ = 'google.ads.google_ads.v0.proto.common.ad_type_infos_pb2'
  ,
  __doc__ = """An expanded dynamic search ad.
  
  
  Attributes:
      description:
          The description of the ad.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v0.common.ExpandedDynamicSearchAdInfo)
  ))
_sym_db.RegisterMessage(ExpandedDynamicSearchAdInfo)

HotelAdInfo = _reflection.GeneratedProtocolMessageType('HotelAdInfo', (_message.Message,), dict(
  DESCRIPTOR = _HOTELADINFO,
  __module__ = 'google.ads.google_ads.v0.proto.common.ad_type_infos_pb2'
  ,
  __doc__ = """A hotel ad.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v0.common.HotelAdInfo)
  ))
_sym_db.RegisterMessage(HotelAdInfo)

ShoppingSmartAdInfo = _reflection.GeneratedProtocolMessageType('ShoppingSmartAdInfo', (_message.Message,), dict(
  DESCRIPTOR = _SHOPPINGSMARTADINFO,
  __module__ = 'google.ads.google_ads.v0.proto.common.ad_type_infos_pb2'
  ,
  __doc__ = """A Smart Shopping ad.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v0.common.ShoppingSmartAdInfo)
  ))
_sym_db.RegisterMessage(ShoppingSmartAdInfo)

ShoppingProductAdInfo = _reflection.GeneratedProtocolMessageType('ShoppingProductAdInfo', (_message.Message,), dict(
  DESCRIPTOR = _SHOPPINGPRODUCTADINFO,
  __module__ = 'google.ads.google_ads.v0.proto.common.ad_type_infos_pb2'
  ,
  __doc__ = """A standard Shopping ad.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v0.common.ShoppingProductAdInfo)
  ))
_sym_db.RegisterMessage(ShoppingProductAdInfo)

GmailAdInfo = _reflection.GeneratedProtocolMessageType('GmailAdInfo', (_message.Message,), dict(
  DESCRIPTOR = _GMAILADINFO,
  __module__ = 'google.ads.google_ads.v0.proto.common.ad_type_infos_pb2'
  ,
  __doc__ = """A Gmail ad.
  
  
  Attributes:
      teaser:
          The Gmail teaser.
      header_image:
          The MediaFile resource name of the header image. Valid image
          types are GIF, JPEG and PNG. The minimum size is 300x100
          pixels and the aspect ratio must be between 3:1 and 5:1
          (+-1%).
      marketing_image:
          The MediaFile resource name of the marketing image. Valid
          image types are GIF, JPEG and PNG. The image must either be
          landscape with a minimum size of 600x314 pixels and aspect
          ratio of 600:314 (+-1%) or square with a minimum size of
          300x300 pixels and aspect ratio of 1:1 (+-1%)
      marketing_image_headline:
          Headline of the marketing image.
      marketing_image_description:
          Description of the marketing image.
      marketing_image_display_call_to_action:
          Display-call-to-action of the marketing image.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v0.common.GmailAdInfo)
  ))
_sym_db.RegisterMessage(GmailAdInfo)

GmailTeaser = _reflection.GeneratedProtocolMessageType('GmailTeaser', (_message.Message,), dict(
  DESCRIPTOR = _GMAILTEASER,
  __module__ = 'google.ads.google_ads.v0.proto.common.ad_type_infos_pb2'
  ,
  __doc__ = """Gmail teaser data. The teaser is a small header that acts as an
  invitation to view the rest of the ad (the body).
  
  
  Attributes:
      headline:
          Headline of the teaser.
      description:
          Description of the teaser.
      business_name:
          Business name of the advertiser.
      logo_image:
          The MediaFile resource name of the logo image. Valid image
          types are GIF, JPEG and PNG. The minimum size is 144x144
          pixels and the aspect ratio must be 1:1 (+-1%).
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v0.common.GmailTeaser)
  ))
_sym_db.RegisterMessage(GmailTeaser)

DisplayCallToAction = _reflection.GeneratedProtocolMessageType('DisplayCallToAction', (_message.Message,), dict(
  DESCRIPTOR = _DISPLAYCALLTOACTION,
  __module__ = 'google.ads.google_ads.v0.proto.common.ad_type_infos_pb2'
  ,
  __doc__ = """Data for display call to action. The call to action is a piece of the ad
  that prompts the user to do something. Like clicking a link or making a
  phone call.
  
  
  Attributes:
      text:
          Text for the display-call-to-action.
      text_color:
          Text color for the display-call-to-action in hexadecimal, e.g.
          #ffffff for white.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v0.common.DisplayCallToAction)
  ))
_sym_db.RegisterMessage(DisplayCallToAction)

ImageAdInfo = _reflection.GeneratedProtocolMessageType('ImageAdInfo', (_message.Message,), dict(
  DESCRIPTOR = _IMAGEADINFO,
  __module__ = 'google.ads.google_ads.v0.proto.common.ad_type_infos_pb2'
  ,
  __doc__ = """An image ad.
  
  
  Attributes:
      pixel_width:
          Width in pixels of the full size image.
      pixel_height:
          Height in pixels of the full size image.
      image_url:
          URL of the full size image.
      preview_pixel_width:
          Width in pixels of the preview size image.
      preview_pixel_height:
          Height in pixels of the preview size image.
      preview_image_url:
          URL of the preview size image.
      mime_type:
          The mime type of the image.
      name:
          The name of the image. If the image was created from a
          MediaFile, this is the MediaFile's name. If the image was
          created from bytes, this is empty.
      image:
          The image to create the ImageAd from. This can be specified in
          one of two ways. 1. An existing MediaFile resource. 2. The raw
          image data as bytes.
      media_file:
          The MediaFile resource to use for the image.
      data:
          Raw image data as bytes.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v0.common.ImageAdInfo)
  ))
_sym_db.RegisterMessage(ImageAdInfo)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n\"com.google.ads.googleads.v0.commonB\020AdTypeInfosProtoP\001ZDgoogle.golang.org/genproto/googleapis/ads/googleads/v0/common;common\242\002\003GAA\252\002\036Google.Ads.GoogleAds.V0.Common\312\002\036Google\\Ads\\GoogleAds\\V0\\Common'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v0/proto/services/campaign_shared_set_service.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.ads.google_ads.v0.proto.resources import campaign_shared_set_pb2 as google_dot_ads_dot_googleads__v0_dot_proto_dot_resources_dot_campaign__shared__set__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v0/proto/services/campaign_shared_set_service.proto',
  package='google.ads.googleads.v0.services',
  syntax='proto3',
  serialized_pb=_b('\nHgoogle/ads/googleads_v0/proto/services/campaign_shared_set_service.proto\x12 google.ads.googleads.v0.services\x1a\x41google/ads/googleads_v0/proto/resources/campaign_shared_set.proto\x1a\x1cgoogle/api/annotations.proto\"4\n\x1bGetCampaignSharedSetRequest\x12\x15\n\rresource_name\x18\x01 \x01(\t\"\x88\x01\n\x1fMutateCampaignSharedSetsRequest\x12\x13\n\x0b\x63ustomer_id\x18\x01 \x01(\t\x12P\n\noperations\x18\x02 \x03(\x0b\x32<.google.ads.googleads.v0.services.CampaignSharedSetOperation\"\x83\x01\n\x1a\x43\x61mpaignSharedSetOperation\x12\x46\n\x06\x63reate\x18\x01 \x01(\x0b\x32\x34.google.ads.googleads.v0.resources.CampaignSharedSetH\x00\x12\x10\n\x06remove\x18\x03 \x01(\tH\x00\x42\x0b\n\toperation\"t\n MutateCampaignSharedSetsResponse\x12P\n\x07results\x18\x02 \x03(\x0b\x32?.google.ads.googleads.v0.services.MutateCampaignSharedSetResult\"6\n\x1dMutateCampaignSharedSetResult\x12\x15\n\rresource_name\x18\x01 \x01(\t2\xce\x03\n\x18\x43\x61mpaignSharedSetService\x12\xc9\x01\n\x14GetCampaignSharedSet\x12=.google.ads.googleads.v0.services.GetCampaignSharedSetRequest\x1a\x34.google.ads.googleads.v0.resources.CampaignSharedSet\"<\x82\xd3\xe4\x93\x02\x36\x12\x34/v0/{resource_name=customers/*/campaignSharedSets/*}\x12\xe5\x01\n\x18MutateCampaignSharedSets\x12\x41.google.ads.googleads.v0.services.MutateCampaignSharedSetsRequest\x1a\x42.google.ads.googleads.v0.services.MutateCampaignSharedSetsResponse\"B\x82\xd3\xe4\x93\x02<\"7/v0/customers/{customer_id=*}/campaignSharedSets:mutate:\x01*B\xdd\x01\n$com.google.ads.googleads.v0.servicesB\x1d\x43\x61mpaignSharedSetServiceProtoP\x01ZHgoogle.golang.org/genproto/googleapis/ads/googleads/v0/services;services\xa2\x02\x03GAA\xaa\x02 Google.Ads.GoogleAds.V0.Services\xca\x02 Google\\Ads\\GoogleAds\\V0\\Servicesb\x06proto3')
  ,
  dependencies=[google_dot_ads_dot_googleads__v0_dot_proto_dot_resources_dot_campaign__shared__set__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,])




_GETCAMPAIGNSHAREDSETREQUEST = _descriptor.Descriptor(
  name='GetCampaignSharedSetRequest',
  full_name='google.ads.googleads.v0.services.GetCampaignSharedSetRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_name', full_name='google.ads.googleads.v0.services.GetCampaignSharedSetRequest.resource_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=207,
  serialized_end=259,
)


_MUTATECAMPAIGNSHAREDSETSREQUEST = _descriptor.Descriptor(
  name='MutateCampaignSharedSetsRequest',
  full_name='google.ads.googleads.v0.services.MutateCampaignSharedSetsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='customer_id', full_name='google.ads.googleads.v0.services.MutateCampaignSharedSetsRequest.customer_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='operations', full_name='google.ads.googleads.v0.services.MutateCampaignSharedSetsRequest.operations', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=262,
  serialized_end=398,
)


_CAMPAIGNSHAREDSETOPERATION = _descriptor.Descriptor(
  name='CampaignSharedSetOperation',
  full_name='google.ads.googleads.v0.services.CampaignSharedSetOperation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='create', full_name='google.ads.googleads.v0.services.CampaignSharedSetOperation.create', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='remove', full_name='google.ads.googleads.v0.services.CampaignSharedSetOperation.remove', index=1,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='operation', full_name='google.ads.googleads.v0.services.CampaignSharedSetOperation.operation',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=401,
  serialized_end=532,
)


_MUTATECAMPAIGNSHAREDSETSRESPONSE = _descriptor.Descriptor(
  name='MutateCampaignSharedSetsResponse',
  full_name='google.ads.googleads.v0.services.MutateCampaignSharedSetsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='results', full_name='google.ads.googleads.v0.services.MutateCampaignSharedSetsResponse.results', index=0,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=534,
  serialized_end=650,
)


_MUTATECAMPAIGNSHAREDSETRESULT = _descriptor.Descriptor(
  name='MutateCampaignSharedSetResult',
  full_name='google.ads.googleads.v0.services.MutateCampaignSharedSetResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_name', full_name='google.ads.googleads.v0.services.MutateCampaignSharedSetResult.resource_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=652,
  serialized_end=706,
)

_MUTATECAMPAIGNSHAREDSETSREQUEST.fields_by_name['operations'].message_type = _CAMPAIGNSHAREDSETOPERATION
_CAMPAIGNSHAREDSETOPERATION.fields_by_name['create'].message_type = google_dot_ads_dot_googleads__v0_dot_proto_dot_resources_dot_campaign__shared__set__pb2._CAMPAIGNSHAREDSET
_CAMPAIGNSHAREDSETOPERATION.oneofs_by_name['operation'].fields.append(
  _CAMPAIGNSHAREDSETOPERATION.fields_by_name['create'])
_CAMPAIGNSHAREDSETOPERATION.fields_by_name['create'].containing_oneof = _CAMPAIGNSHAREDSETOPERATION.oneofs_by_name['operation']
_CAMPAIGNSHAREDSETOPERATION.oneofs_by_name['operation'].fields.append(
  _CAMPAIGNSHAREDSETOPERATION.fields_by_name['remove'])
_CAMPAIGNSHAREDSETOPERATION.fields_by_name['remove'].containing_oneof = _CAMPAIGNSHAREDSETOPERATION.oneofs_by_name['operation']
_MUTATECAMPAIGNSHAREDSETSRESPONSE.fields_by_name['results'].message_type = _MUTATECAMPAIGNSHAREDSETRESULT
DESCRIPTOR.message_types_by_name['GetCampaignSharedSetRequest'] = _GETCAMPAIGNSHAREDSETREQUEST
DESCRIPTOR.message_types_by_name['MutateCampaignSharedSetsRequest'] = _MUTATECAMPAIGNSHAREDSETSREQUEST
DESCRIPTOR.message_types_by_name['CampaignSharedSetOperation'] = _CAMPAIGNSHAREDSETOPERATION
DESCRIPTOR.message_types_by_name['MutateCampaignSharedSetsResponse'] = _MUTATECAMPAIGNSHAREDSETSRESPONSE
DESCRIPTOR.message_types_by_name['MutateCampaignSharedSetResult'] = _MUTATECAMPAIGNSHAREDSETRESULT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetCampaignSharedSetRequest = _reflection.GeneratedProtocolMessageType('GetCampaignSharedSetRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETCAMPAIGNSHAREDSETREQUEST,
  __module__ = 'google.ads.google_ads.v0.proto.services.campaign_shared_set_service_pb2'
  ,
  __doc__ = """Request message for
  [CampaignSharedSetService.GetCampaignSharedSet][google.ads.googleads.v0.services.CampaignSharedSetService.GetCampaignSharedSet].
  
  
  Attributes:
      resource_name:
          The resource name of the campaign shared set to fetch.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v0.services.GetCampaignSharedSetRequest)
  ))
_sym_db.RegisterMessage(GetCampaignSharedSetRequest)

MutateCampaignSharedSetsRequest = _reflection.GeneratedProtocolMessageType('MutateCampaignSharedSetsRequest', (_message.Message,), dict(
  DESCRIPTOR = _MUTATECAMPAIGNSHAREDSETSREQUEST,
  __module__ = 'google.ads.google_ads.v0.proto.services.campaign_shared_set_service_pb2'
  ,
  __doc__ = """Request message for
  [CampaignSharedSetService.MutateCampaignSharedSets][google.ads.googleads.v0.services.CampaignSharedSetService.MutateCampaignSharedSets].
  
  
  Attributes:
      customer_id:
          The ID of the customer whose campaign shared sets are being
          modified.
      operations:
          The list of operations to perform on individual campaign
          shared sets.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v0.services.MutateCampaignSharedSetsRequest)
  ))
_sym_db.RegisterMessage(MutateCampaignSharedSetsRequest)

CampaignSharedSetOperation = _reflection.GeneratedProtocolMessageType('CampaignSharedSetOperation', (_message.Message,), dict(
  DESCRIPTOR = _CAMPAIGNSHAREDSETOPERATION,
  __module__ = 'google.ads.google_ads.v0.proto.services.campaign_shared_set_service_pb2'
  ,
  __doc__ = """A single operation (create, remove) on an campaign shared set.
  
  
  Attributes:
      operation:
          The mutate operation.
      create:
          Create operation: No resource name is expected for the new
          campaign shared set.
      remove:
          Remove operation: A resource name for the removed campaign
          shared set is expected, in this format:  ``customers/{customer
          _id}/campaignSharedSets/{campaign_id}_{shared_set_id}``
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v0.services.CampaignSharedSetOperation)
  ))
_sym_db.RegisterMessage(CampaignSharedSetOperation)

MutateCampaignSharedSetsResponse = _reflection.GeneratedProtocolMessageType('MutateCampaignSharedSetsResponse', (_message.Message,), dict(
  DESCRIPTOR = _MUTATECAMPAIGNSHAREDSETSRESPONSE,
  __module__ = 'google.ads.google_ads.v0.proto.services.campaign_shared_set_service_pb2'
  ,
  __doc__ = """Response message for a campaign shared set mutate.
  
  
  Attributes:
      results:
          All results for the mutate.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v0.services.MutateCampaignSharedSetsResponse)
  ))
_sym_db.RegisterMessage(MutateCampaignSharedSetsResponse)

MutateCampaignSharedSetResult = _reflection.GeneratedProtocolMessageType('MutateCampaignSharedSetResult', (_message.Message,), dict(
  DESCRIPTOR = _MUTATECAMPAIGNSHAREDSETRESULT,
  __module__ = 'google.ads.google_ads.v0.proto.services.campaign_shared_set_service_pb2'
  ,
  __doc__ = """The result for the campaign shared set mutate.
  
  
  Attributes:
      resource_name:
          Returned for successful operations.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v0.services.MutateCampaignSharedSetResult)
  ))
_sym_db.RegisterMessage(MutateCampaignSharedSetResult)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n$com.google.ads.googleads.v0.servicesB\035CampaignSharedSetServiceProtoP\001ZHgoogle.golang.org/genproto/googleapis/ads/googleads/v0/services;services\242\002\003GAA\252\002 Google.Ads.GoogleAds.V0.Services\312\002 Google\\Ads\\GoogleAds\\V0\\Services'))

_CAMPAIGNSHAREDSETSERVICE = _descriptor.ServiceDescriptor(
  name='CampaignSharedSetService',
  full_name='google.ads.googleads.v0.services.CampaignSharedSetService',
  file=DESCRIPTOR,
  index=0,
  options=None,
  serialized_start=709,
  serialized_end=1171,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetCampaignSharedSet',
    full_name='google.ads.googleads.v0.services.CampaignSharedSetService.GetCampaignSharedSet',
    index=0,
    containing_service=None,
    input_type=_GETCAMPAIGNSHAREDSETREQUEST,
    output_type=google_dot_ads_dot_googleads__v0_dot_proto_dot_resources_dot_campaign__shared__set__pb2._CAMPAIGNSHAREDSET,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), _b('\202\323\344\223\0026\0224/v0/{resource_name=customers/*/campaignSharedSets/*}')),
  ),
  _descriptor.MethodDescriptor(
    name='MutateCampaignSharedSets',
    full_name='google.ads.googleads.v0.services.CampaignSharedSetService.MutateCampaignSharedSets',
    index=1,
    containing_service=None,
    input_type=_MUTATECAMPAIGNSHAREDSETSREQUEST,
    output_type=_MUTATECAMPAIGNSHAREDSETSRESPONSE,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), _b('\202\323\344\223\002<\"7/v0/customers/{customer_id=*}/campaignSharedSets:mutate:\001*')),
  ),
])
_sym_db.RegisterServiceDescriptor(_CAMPAIGNSHAREDSETSERVICE)

DESCRIPTOR.services_by_name['CampaignSharedSetService'] = _CAMPAIGNSHAREDSETSERVICE

# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v0/proto/resources/campaign_audience_view.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v0/proto/resources/campaign_audience_view.proto',
  package='google.ads.googleads.v0.resources',
  syntax='proto3',
  serialized_pb=_b('\nDgoogle/ads/googleads_v0/proto/resources/campaign_audience_view.proto\x12!google.ads.googleads.v0.resources\"-\n\x14\x43\x61mpaignAudienceView\x12\x15\n\rresource_name\x18\x01 \x01(\tB\xde\x01\n%com.google.ads.googleads.v0.resourcesB\x19\x43\x61mpaignAudienceViewProtoP\x01ZJgoogle.golang.org/genproto/googleapis/ads/googleads/v0/resources;resources\xa2\x02\x03GAA\xaa\x02!Google.Ads.GoogleAds.V0.Resources\xca\x02!Google\\Ads\\GoogleAds\\V0\\Resourcesb\x06proto3')
)




_CAMPAIGNAUDIENCEVIEW = _descriptor.Descriptor(
  name='CampaignAudienceView',
  full_name='google.ads.googleads.v0.resources.CampaignAudienceView',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_name', full_name='google.ads.googleads.v0.resources.CampaignAudienceView.resource_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=107,
  serialized_end=152,
)

DESCRIPTOR.message_types_by_name['CampaignAudienceView'] = _CAMPAIGNAUDIENCEVIEW
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CampaignAudienceView = _reflection.GeneratedProtocolMessageType('CampaignAudienceView', (_message.Message,), dict(
  DESCRIPTOR = _CAMPAIGNAUDIENCEVIEW,
  __module__ = 'google.ads.google_ads.v0.proto.resources.campaign_audience_view_pb2'
  ,
  __doc__ = """A campaign audience view. Includes performance data from interests and
  remarketing lists for Display Network and YouTube Network ads, and
  remarketing lists for search ads (RLSA), aggregated by campaign and
  audience criterion. This view only includes audiences attached at the
  campaign level.
  
  
  Attributes:
      resource_name:
          The resource name of the campaign audience view. Campaign
          audience view resource names have the form:  ``customers/{cust
          omer_id}/campaignAudienceViews/{campaign_id}_{criterion_id}``
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v0.resources.CampaignAudienceView)
  ))
_sym_db.RegisterMessage(CampaignAudienceView)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n%com.google.ads.googleads.v0.resourcesB\031CampaignAudienceViewProtoP\001ZJgoogle.golang.org/genproto/googleapis/ads/googleads/v0/resources;resources\242\002\003GAA\252\002!Google.Ads.GoogleAds.V0.Resources\312\002!Google\\Ads\\GoogleAds\\V0\\Resources'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v0/proto/errors/ad_group_feed_error.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v0/proto/errors/ad_group_feed_error.proto',
  package='google.ads.googleads.v0.errors',
  syntax='proto3',
  serialized_pb=_b('\n>google/ads/googleads_v0/proto/errors/ad_group_feed_error.proto\x12\x1egoogle.ads.googleads.v0.errors\"\xdc\x02\n\x14\x41\x64GroupFeedErrorEnum\"\xc3\x02\n\x10\x41\x64GroupFeedError\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x0b\n\x07UNKNOWN\x10\x01\x12,\n(FEED_ALREADY_EXISTS_FOR_PLACEHOLDER_TYPE\x10\x02\x12\"\n\x1e\x43\x41NNOT_CREATE_FOR_REMOVED_FEED\x10\x03\x12\x1f\n\x1b\x41\x44GROUP_FEED_ALREADY_EXISTS\x10\x04\x12*\n&CANNOT_OPERATE_ON_REMOVED_ADGROUP_FEED\x10\x05\x12\x1c\n\x18INVALID_PLACEHOLDER_TYPE\x10\x06\x12,\n(MISSING_FEEDMAPPING_FOR_PLACEHOLDER_TYPE\x10\x07\x12&\n\"NO_EXISTING_LOCATION_CUSTOMER_FEED\x10\x08\x42\xcb\x01\n\"com.google.ads.googleads.v0.errorsB\x15\x41\x64GroupFeedErrorProtoP\x01ZDgoogle.golang.org/genproto/googleapis/ads/googleads/v0/errors;errors\xa2\x02\x03GAA\xaa\x02\x1eGoogle.Ads.GoogleAds.V0.Errors\xca\x02\x1eGoogle\\Ads\\GoogleAds\\V0\\Errorsb\x06proto3')
)



_ADGROUPFEEDERRORENUM_ADGROUPFEEDERROR = _descriptor.EnumDescriptor(
  name='AdGroupFeedError',
  full_name='google.ads.googleads.v0.errors.AdGroupFeedErrorEnum.AdGroupFeedError',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FEED_ALREADY_EXISTS_FOR_PLACEHOLDER_TYPE', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CANNOT_CREATE_FOR_REMOVED_FEED', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ADGROUP_FEED_ALREADY_EXISTS', index=4, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CANNOT_OPERATE_ON_REMOVED_ADGROUP_FEED', index=5, number=5,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_PLACEHOLDER_TYPE', index=6, number=6,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MISSING_FEEDMAPPING_FOR_PLACEHOLDER_TYPE', index=7, number=7,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NO_EXISTING_LOCATION_CUSTOMER_FEED', index=8, number=8,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=124,
  serialized_end=447,
)
_sym_db.RegisterEnumDescriptor(_ADGROUPFEEDERRORENUM_ADGROUPFEEDERROR)


_ADGROUPFEEDERRORENUM = _descriptor.Descriptor(
  name='AdGroupFeedErrorEnum',
  full_name='google.ads.googleads.v0.errors.AdGroupFeedErrorEnum',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _ADGROUPFEEDERRORENUM_ADGROUPFEEDERROR,
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=99,
  serialized_end=447,
)

_ADGROUPFEEDERRORENUM_ADGROUPFEEDERROR.containing_type = _ADGROUPFEEDERRORENUM
DESCRIPTOR.message_types_by_name['AdGroupFeedErrorEnum'] = _ADGROUPFEEDERRORENUM
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

AdGroupFeedErrorEnum = _reflection.GeneratedProtocolMessageType('AdGroupFeedErrorEnum', (_message.Message,), dict(
  DESCRIPTOR = _ADGROUPFEEDERRORENUM,
  __module__ = 'google.ads.google_ads.v0.proto.errors.ad_group_feed_error_pb2'
  ,
  __doc__ = """Container for enum describing possible ad group feed errors.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v0.errors.AdGroupFeedErrorEnum)
  ))
_sym_db.RegisterMessage(AdGroupFeedErrorEnum)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n\"com.google.ads.googleads.v0.errorsB\025AdGroupFeedErrorProtoP\001ZDgoogle.golang.org/genproto/googleapis/ads/googleads/v0/errors;errors\242\002\003GAA\252\002\036Google.Ads.GoogleAds.V0.Errors\312\002\036Google\\Ads\\GoogleAds\\V0\\Errors'))
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from google.ads.google_ads.v0.proto.resources import campaign_budget_pb2 as google_dot_ads_dot_googleads__v0_dot_proto_dot_resources_dot_campaign__budget__pb2
from google.ads.google_ads.v0.proto.services import campaign_budget_service_pb2 as google_dot_ads_dot_googleads__v0_dot_proto_dot_services_dot_campaign__budget__service__pb2


class CampaignBudgetServiceStub(object):
  """Service to manage campaign budgets.
  """

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.GetCampaignBudget = channel.unary_unary(
        '/google.ads.googleads.v0.services.CampaignBudgetService/GetCampaignBudget',
        request_serializer=google_dot_ads_dot_googleads__v0_dot_proto_dot_services_dot_campaign__budget__service__pb2.GetCampaignBudgetRequest.SerializeToString,
        response_deserializer=google_dot_ads_dot_googleads__v0_dot_proto_dot_resources_dot_campaign__budget__pb2.CampaignBudget.FromString,
        )
    self.MutateCampaignBudgets = channel.unary_unary(
        '/google.ads.googleads.v0.services.CampaignBudgetService/MutateCampaignBudgets',
        request_serializer=google_dot_ads_dot_googleads__v0_dot_proto_dot_services_dot_campaign__budget__service__pb2.MutateCampaignBudgetsRequest.SerializeToString,
        response_deserializer=google_dot_ads_dot_googleads__v0_dot_proto_dot_services_dot_campaign__budget__service__pb2.MutateCampaignBudgetsResponse.FromString,
        )


class CampaignBudgetServiceServicer(object):
  """Service to manage campaign budgets.
  """

  def GetCampaignBudget(self, request, context):
    """Returns the requested Campaign Budget in full detail.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def MutateCampaignBudgets(self, request, context):
    """Creates, updates, or removes campaign budgets. Operation statuses are
    returned.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_CampaignBudgetServiceServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'GetCampaignBudget': grpc.unary_unary_rpc_method_handler(
          servicer.GetCampaignBudget,
          request_deserializer=google_dot_ads_dot_googleads__v0_dot_proto_dot_services_dot_campaign__budget__service__pb2.GetCampaignBudgetRequest.FromString,
          response_serializer=google_dot_ads_dot_googleads__v0_dot_proto_dot_resources_dot_campaign__budget__pb2.CampaignBudget.SerializeToString,
      ),
      'MutateCampaignBudgets': grpc.unary_unary_rpc_method_handler(
          servicer.MutateCampaignBudgets,
          request_deserializer=google_dot_ads_dot_googleads__v0_dot_proto_dot_services_dot_campaign__budget__service__pb2.MutateCampaignBudgetsRequest.FromString,
          response_serializer=google_dot_ads_dot_googleads__v0_dot_proto_dot_services_dot_campaign__budget__service__pb2.MutateCampaignBudgetsResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'google.ads.googleads.v0.services.CampaignBudgetService', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v0/proto/services/ad_group_criterion_service.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.ads.google_ads.v0.proto.resources import ad_group_criterion_pb2 as google_dot_ads_dot_googleads__v0_dot_proto_dot_resources_dot_ad__group__criterion__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v0/proto/services/ad_group_criterion_service.proto',
  package='google.ads.googleads.v0.services',
  syntax='proto3',
  serialized_pb=_b('\nGgoogle/ads/googleads_v0/proto/services/ad_group_criterion_service.proto\x12 google.ads.googleads.v0.services\x1a@google/ads/googleads_v0/proto/resources/ad_group_criterion.proto\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\"3\n\x1aGetAdGroupCriterionRequest\x12\x15\n\rresource_name\x18\x01 \x01(\t\"\x84\x01\n\x1cMutateAdGroupCriteriaRequest\x12\x13\n\x0b\x63ustomer_id\x18\x01 \x01(\t\x12O\n\noperations\x18\x02 \x03(\x0b\x32;.google.ads.googleads.v0.services.AdGroupCriterionOperation\"\xf9\x01\n\x19\x41\x64GroupCriterionOperation\x12/\n\x0bupdate_mask\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x45\n\x06\x63reate\x18\x01 \x01(\x0b\x32\x33.google.ads.googleads.v0.resources.AdGroupCriterionH\x00\x12\x45\n\x06update\x18\x02 \x01(\x0b\x32\x33.google.ads.googleads.v0.resources.AdGroupCriterionH\x00\x12\x10\n\x06remove\x18\x03 \x01(\tH\x00\x42\x0b\n\toperation\"p\n\x1dMutateAdGroupCriteriaResponse\x12O\n\x07results\x18\x02 \x03(\x0b\x32>.google.ads.googleads.v0.services.MutateAdGroupCriterionResult\"5\n\x1cMutateAdGroupCriterionResult\x12\x15\n\rresource_name\x18\x01 \x01(\t2\xbb\x03\n\x17\x41\x64GroupCriterionService\x12\xc3\x01\n\x13GetAdGroupCriterion\x12<.google.ads.googleads.v0.services.GetAdGroupCriterionRequest\x1a\x33.google.ads.googleads.v0.resources.AdGroupCriterion\"9\x82\xd3\xe4\x93\x02\x33\x12\x31/v0/{resource_name=customers/*/adGroupCriteria/*}\x12\xd9\x01\n\x15MutateAdGroupCriteria\x12>.google.ads.googleads.v0.services.MutateAdGroupCriteriaRequest\x1a?.google.ads.googleads.v0.services.MutateAdGroupCriteriaResponse\"?\x82\xd3\xe4\x93\x02\x39\"4/v0/customers/{customer_id=*}/adGroupCriteria:mutate:\x01*B\xdc\x01\n$com.google.ads.googleads.v0.servicesB\x1c\x41\x64GroupCriterionServiceProtoP\x01ZHgoogle.golang.org/genproto/googleapis/ads/googleads/v0/services;services\xa2\x02\x03GAA\xaa\x02 Google.Ads.GoogleAds.V0.Services\xca\x02 Google\\Ads\\GoogleAds\\V0\\Servicesb\x06proto3')
  ,
  dependencies=[google_dot_ads_dot_googleads__v0_dot_proto_dot_resources_dot_ad__group__criterion__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,google_dot_protobuf_dot_field__mask__pb2.DESCRIPTOR,])




_GETADGROUPCRITERIONREQUEST = _descriptor.Descriptor(
  name='GetAdGroupCriterionRequest',
  full_name='google.ads.googleads.v0.services.GetAdGroupCriterionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_name', full_name='google.ads.googleads.v0.services.GetAdGroupCriterionRequest.resource_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=239,
  serialized_end=290,
)


_MUTATEADGROUPCRITERIAREQUEST = _descriptor.Descriptor(
  name='MutateAdGroupCriteriaRequest',
  full_name='google.ads.googleads.v0.services.MutateAdGroupCriteriaRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='customer_id', full_name='google.ads.googleads.v0.services.MutateAdGroupCriteriaRequest.customer_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='operations', full_name='google.ads.googleads.v0.services.MutateAdGroupCriteriaRequest.operations', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=293,
  serialized_end=425,
)


_ADGROUPCRITERIONOPERATION = _descriptor.Descriptor(
  name='AdGroupCriterionOperation',
  full_name='google.ads.googleads.v0.services.AdGroupCriterionOperation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='update_mask', full_name='google.ads.googleads.v0.services.AdGroupCriterionOperation.update_mask', index=0,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='create', full_name='google.ads.googleads.v0.services.AdGroupCriterionOperation.create', index=1,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='update', full_name='google.ads.googleads.v0.services.AdGroupCriterionOperation.update', index=2,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='remove', full_name='google.ads.googleads.v0.services.AdGroupCriterionOperation.remove', index=3,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='operation', full_name='google.ads.googleads.v0.services.AdGroupCriterionOperation.operation',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=428,
  serialized_end=677,
)


_MUTATEADGROUPCRITERIARESPONSE = _descriptor.Descriptor(
  name='MutateAdGroupCriteriaResponse',
  full_name='google.ads.googleads.v0.services.MutateAdGroupCriteriaResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='results', full_name='google.ads.googleads.v0.services.MutateAdGroupCriteriaResponse.results', index=0,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=679,
  serialized_end=791,
)


_MUTATEADGROUPCRITERIONRESULT = _descriptor.Descriptor(
  name='MutateAdGroupCriterionResult',
  full_name='google.ads.googleads.v0.services.MutateAdGroupCriterionResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_name', full_name='google.ads.googleads.v0.services.MutateAdGroupCriterionResult.resource_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=793,
  serialized_end=846,
)

_MUTATEADGROUPCRITERIAREQUEST.fields_by_name['operations'].message_type = _ADGROUPCRITERIONOPERATION
_ADGROUPCRITERIONOPERATION.fields_by_name['update_mask'].message_type = google_dot_protobuf_dot_field__mask__pb2._FIELDMASK
_ADGROUPCRITERIONOPERATION.fields_by_name['create'].message_type = google_dot_ads_dot_googleads__v0_dot_proto_dot_resources_dot_ad__group__criterion__pb2._ADGROUPCRITERION
_ADGROUPCRITERIONOPERATION.fields_by_name['update'].message_type = google_dot_ads_dot_googleads__v0_dot_proto_dot_resources_dot_ad__group__criterion__pb2._ADGROUPCRITERION
_ADGROUPCRITERIONOPERATION.oneofs_by_name['operation'].fields.append(
  _ADGROUPCRITERIONOPERATION.fields_by_name['create'])
_ADGROUPCRITERIONOPERATION.fields_by_name['create'].containing_oneof = _ADGROUPCRITERIONOPERATION.oneofs_by_name['operation']
_ADGROUPCRITERIONOPERATION.oneofs_by_name['operation'].fields.append(
  _ADGROUPCRITERIONOPERATION.fields_by_name['update'])
_ADGROUPCRITERIONOPERATION.fields_by_name['update'].containing_oneof = _ADGROUPCRITERIONOPERATION.oneofs_by_name['operation']
_ADGROUPCRITERIONOPERATION.oneofs_by_name['operation'].fields.append(
  _ADGROUPCRITERIONOPERATION.fields_by_name['remove'])
_ADGROUPCRITERIONOPERATION.fields_by_name['remove'].containing_oneof = _ADGROUPCRITERIONOPERATION.oneofs_by_name['operation']
_MUTATEADGROUPCRITERIARESPONSE.fields_by_name['results'].message_type = _MUTATEADGROUPCRITERIONRESULT
DESCRIPTOR.message_types_by_name['GetAdGroupCriterionRequest'] = _GETADGROUPCRITERIONREQUEST
DESCRIPTOR.message_types_by_name['MutateAdGroupCriteriaRequest'] = _MUTATEADGROUPCRITERIAREQUEST
DESCRIPTOR.message_types_by_name['AdGroupCriterionOperation'] = _ADGROUPCRITERIONOPERATION
DESCRIPTOR.message_types_by_name['MutateAdGroupCriteriaResponse'] = _MUTATEADGROUPCRITERIARESPONSE
DESCRIPTOR.message_types_by_name['MutateAdGroupCriterionResult'] = _MUTATEADGROUPCRITERIONRESULT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetAdGroupCriterionRequest = _reflection.GeneratedProtocolMessageType('GetAdGroupCriterionRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETADGROUPCRITERIONREQUEST,
  __module__ = 'google.ads.google_ads.v0.proto.services.ad_group_criterion_service_pb2'
  ,
  __doc__ = """Request message for
  [AdGroupCriterionService.GetAdGroupCriterion][google.ads.googleads.v0.services.AdGroupCriterionService.GetAdGroupCriterion].
  
  
  Attributes:
      resource_name:
          The resource name of the criterion to fetch.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v0.services.GetAdGroupCriterionRequest)
  ))
_sym_db.RegisterMessage(GetAdGroupCriterionRequest)

MutateAdGroupCriteriaRequest = _reflection.GeneratedProtocolMessageType('MutateAdGroupCriteriaRequest', (_message.Message,), dict(
  DESCRIPTOR = _MUTATEADGROUPCRITERIAREQUEST,
  __module__ = 'google.ads.google_ads.v0.proto.services.ad_group_criterion_service_pb2'
  ,
  __doc__ = """Request message for
  [AdGroupCriterionService.MutateAdGroupCriteria][google.ads.googleads.v0.services.AdGroupCriterionService.MutateAdGroupCriteria].
  
  
  Attributes:
      customer_id:
          ID of the customer whose criteria are being modified.
      operations:
          The list of operations to perform on individual criteria.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v0.services.MutateAdGroupCriteriaRequest)
  ))
_sym_db.RegisterMessage(MutateAdGroupCriteriaRequest)

AdGroupCriterionOperation = _reflection.GeneratedProtocolMessageType('AdGroupCriterionOperation', (_message.Message,), dict(
  DESCRIPTOR = _ADGROUPCRITERIONOPERATION,
  __module__ = 'google.ads.google_ads.v0.proto.services.ad_group_criterion_service_pb2'
  ,
  __doc__ = """A single operation (create, remove, update) on an ad group criterion.
  
  
  Attributes:
      update_mask:
          FieldMask that determines which resource fields are modified
          in an update.
      operation:
          The mutate operation.
      create:
          Create operation: No resource name is expected for the new
          criterion.
      update:
          Update operation: The criterion is expected to have a valid
          resource name.
      remove:
          Remove operation: A resource name for the removed criterion is
          expected, in this format:  ``customers/{customer_id}/adGroupCr
          iteria/{ad_group_id}_{criterion_id}``
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v0.services.AdGroupCriterionOperation)
  ))
_sym_db.RegisterMessage(AdGroupCriterionOperation)

MutateAdGroupCriteriaResponse = _reflection.GeneratedProtocolMessageType('MutateAdGroupCriteriaResponse', (_message.Message,), dict(
  DESCRIPTOR = _MUTATEADGROUPCRITERIARESPONSE,
  __module__ = 'google.ads.google_ads.v0.proto.services.ad_group_criterion_service_pb2'
  ,
  __doc__ = """Response message for an ad group criterion mutate.
  
  
  Attributes:
      results:
          All results for the mutate.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v0.services.MutateAdGroupCriteriaResponse)
  ))
_sym_db.RegisterMessage(MutateAdGroupCriteriaResponse)

MutateAdGroupCriterionResult = _reflection.GeneratedProtocolMessageType('MutateAdGroupCriterionResult', (_message.Message,), dict(
  DESCRIPTOR = _MUTATEADGROUPCRITERIONRESULT,
  __module__ = 'google.ads.google_ads.v0.proto.services.ad_group_criterion_service_pb2'
  ,
  __doc__ = """The result for the criterion mutate.
  
  
  Attributes:
      resource_name:
          Returned for successful operations.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v0.services.MutateAdGroupCriterionResult)
  ))
_sym_db.RegisterMessage(MutateAdGroupCriterionResult)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n$com.google.ads.googleads.v0.servicesB\034AdGroupCriterionServiceProtoP\001ZHgoogle.golang.org/genproto/googleapis/ads/googleads/v0/services;services\242\002\003GAA\252\002 Google.Ads.GoogleAds.V0.Services\312\002 Google\\Ads\\GoogleAds\\V0\\Services'))

_ADGROUPCRITERIONSERVICE = _descriptor.ServiceDescriptor(
  name='AdGroupCriterionService',
  full_name='google.ads.googleads.v0.services.AdGroupCriterionService',
  file=DESCRIPTOR,
  index=0,
  options=None,
  serialized_start=849,
  serialized_end=1292,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetAdGroupCriterion',
    full_name='google.ads.googleads.v0.services.AdGroupCriterionService.GetAdGroupCriterion',
    index=0,
    containing_service=None,
    input_type=_GETADGROUPCRITERIONREQUEST,
    output_type=google_dot_ads_dot_googleads__v0_dot_proto_dot_resources_dot_ad__group__criterion__pb2._ADGROUPCRITERION,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), _b('\202\323\344\223\0023\0221/v0/{resource_name=customers/*/adGroupCriteria/*}')),
  ),
  _descriptor.MethodDescriptor(
    name='MutateAdGroupCriteria',
    full_name='google.ads.googleads.v0.services.AdGroupCriterionService.MutateAdGroupCriteria',
    index=1,
    containing_service=None,
    input_type=_MUTATEADGROUPCRITERIAREQUEST,
    output_type=_MUTATEADGROUPCRITERIARESPONSE,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), _b('\202\323\344\223\0029\"4/v0/customers/{customer_id=*}/adGroupCriteria:mutate:\001*')),
  ),
])
_sym_db.RegisterServiceDescriptor(_ADGROUPCRITERIONSERVICE)

DESCRIPTOR.services_by_name['AdGroupCriterionService'] = _ADGROUPCRITERIONSERVICE

# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v0/proto/services/customer_client_link_service.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.ads.google_ads.v0.proto.resources import customer_client_link_pb2 as google_dot_ads_dot_googleads__v0_dot_proto_dot_resources_dot_customer__client__link__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v0/proto/services/customer_client_link_service.proto',
  package='google.ads.googleads.v0.services',
  syntax='proto3',
  serialized_pb=_b('\nIgoogle/ads/googleads_v0/proto/services/customer_client_link_service.proto\x12 google.ads.googleads.v0.services\x1a\x42google/ads/googleads_v0/proto/resources/customer_client_link.proto\x1a\x1cgoogle/api/annotations.proto\"5\n\x1cGetCustomerClientLinkRequest\x12\x15\n\rresource_name\x18\x01 \x01(\t2\xeb\x01\n\x19\x43ustomerClientLinkService\x12\xcd\x01\n\x15GetCustomerClientLink\x12>.google.ads.googleads.v0.services.GetCustomerClientLinkRequest\x1a\x35.google.ads.googleads.v0.resources.CustomerClientLink\"=\x82\xd3\xe4\x93\x02\x37\x12\x35/v0/{resource_name=customers/*/customerClientLinks/*}B\xde\x01\n$com.google.ads.googleads.v0.servicesB\x1e\x43ustomerClientLinkServiceProtoP\x01ZHgoogle.golang.org/genproto/googleapis/ads/googleads/v0/services;services\xa2\x02\x03GAA\xaa\x02 Google.Ads.GoogleAds.V0.Services\xca\x02 Google\\Ads\\GoogleAds\\V0\\Servicesb\x06proto3')
  ,
  dependencies=[google_dot_ads_dot_googleads__v0_dot_proto_dot_resources_dot_customer__client__link__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,])




_GETCUSTOMERCLIENTLINKREQUEST = _descriptor.Descriptor(
  name='GetCustomerClientLinkRequest',
  full_name='google.ads.googleads.v0.services.GetCustomerClientLinkRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_name', full_name='google.ads.googleads.v0.services.GetCustomerClientLinkRequest.resource_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=209,
  serialized_end=262,
)

DESCRIPTOR.message_types_by_name['GetCustomerClientLinkRequest'] = _GETCUSTOMERCLIENTLINKREQUEST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetCustomerClientLinkRequest = _reflection.GeneratedProtocolMessageType('GetCustomerClientLinkRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETCUSTOMERCLIENTLINKREQUEST,
  __module__ = 'google.ads.google_ads.v0.proto.services.customer_client_link_service_pb2'
  ,
  __doc__ = """Request message for
  [CustomerClientLinkService.GetCustomerClientLink][google.ads.googleads.v0.services.CustomerClientLinkService.GetCustomerClientLink].
  
  
  Attributes:
      resource_name:
          The resource name of the customer client link to fetch.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v0.services.GetCustomerClientLinkRequest)
  ))
_sym_db.RegisterMessage(GetCustomerClientLinkRequest)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n$com.google.ads.googleads.v0.servicesB\036CustomerClientLinkServiceProtoP\001ZHgoogle.golang.org/genproto/googleapis/ads/googleads/v0/services;services\242\002\003GAA\252\002 Google.Ads.GoogleAds.V0.Services\312\002 Google\\Ads\\GoogleAds\\V0\\Services'))

_CUSTOMERCLIENTLINKSERVICE = _descriptor.ServiceDescriptor(
  name='CustomerClientLinkService',
  full_name='google.ads.googleads.v0.services.CustomerClientLinkService',
  file=DESCRIPTOR,
  index=0,
  options=None,
  serialized_start=265,
  serialized_end=500,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetCustomerClientLink',
    full_name='google.ads.googleads.v0.services.CustomerClientLinkService.GetCustomerClientLink',
    index=0,
    containing_service=None,
    input_type=_GETCUSTOMERCLIENTLINKREQUEST,
    output_type=google_dot_ads_dot_googleads__v0_dot_proto_dot_resources_dot_customer__client__link__pb2._CUSTOMERCLIENTLINK,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), _b('\202\323\344\223\0027\0225/v0/{resource_name=customers/*/customerClientLinks/*}')),
  ),
])
_sym_db.RegisterServiceDescriptor(_CUSTOMERCLIENTLINKSERVICE)

DESCRIPTOR.services_by_name['CustomerClientLinkService'] = _CUSTOMERCLIENTLINKSERVICE

# @@protoc_insertion_point(module_scope)
